/*-----------------------------------------------------------------------------
 * Copyright (c) 2017, 2022, Oracle and/or its affiliates.
 *
 * This software is dual-licensed to you under the Universal Permissive License
 * (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl and Apache License
 * 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose
 * either license.*
 *
 * If you elect to accept the software under the Apache License, Version 2.0,
 * the following applies:
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *-------------------------------------------------------------------------- */

body {
    font-family: -apple-system, BlinkMacSystemFont,
            "Segoe UI", Helvetica, Arial, sans-serif, "Apple Color Emoji",
            "Segoe UI Emoji", "Segoe UI Symbol";
    font-size: 16px;
    line-height: 1.5;
    color: #333;
    background-color: #fff;
}

.clearer {
    clear: both
}

div.header {
    width: 980px;
    margin-right: auto;
    margin-left: auto;
    padding-left: 5px;
}

div.footer {
    padding-top: 10px;
    padding-bottom: 10px;
    text-align: center;
}

table.docutils {
    border-width: thin;
    border-spacing: 0px;
    border-color: #aaa;
}

table.docutils th {
    padding: 3px;
}

table.docutils td {
    padding: 3px;
}

dl.function, dl.member {
    border: 1px solid #888;
    padding: 5px;
}

.document {
    width: 980px;
    margin-right: auto;
    margin-left: auto;
    border: 1px solid #ddd;
    padding: 45px;
}
